--
-- seatCam
-- Specialization for physically seat
-- Specialization fr physikalischen Sitz
--
-- @author  Repi(www.mra-modding.de)
-- @modifications Alex2009(www.alex2009.de)
-- @date  04/12/11
-- 
-- frei verwendbar - keine erlaubnis ntig  |  free for use - no permission needed.
-- Modifikationen erst nach Rcksprache!    |  modifications only with my permission.
--
-- Hinweis: das kopieren von Sourcecode ist strafbar nach UrhG 2.1

seatCam = {};

function seatCam.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function seatCam:load(xmlFile)
	self.cameraRotNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.cameraRotNode#index"));
	self.seatNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.seatNode#index"));
	self.farmerNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.characterNode#index"));
	
	if self.cameraRotNode ~=nil then
		local x,y,z = getTranslation(self.cameraRotNode);
		self.startXTranslation = x;
		self.startYTranslation = y;
		self.startZTranslation = z;
	end;
	
	if self.seatNode ~=nil then
		local x,y,z = getTranslation(self.seatNode);
		self.startSeatXTranslation = x;
		self.startSeatYTranslation = y;
		self.startSeatZTranslation = z;
	end;

	if self.farmerNode ~=nil then
		local x,y,z = getTranslation(self.farmerNode);
		self.startFarmerXTranslation = x;
		self.startFarmerYTranslation = y;
		self.startFarmerZTranslation = z;
	end;
	
	--Sounds
	SeatSoundFile = Utils.getFilename("Sound/seatSound.wav", self.baseDirectory);
    self.SeatSoundId = createSample("SeatSound");
    loadSample(self.SeatSoundId, SeatSoundFile, false);
    self.SeatPlaying = false;
	self.SeatSoundOffset = getSampleDuration(self.SeatSoundId);
	
	self.maxTranslationPrCycle = 0.00008;
	self.offsetTranslation = 0;
	self.offsetAdjustmentTranslation = 0;
	
	if self.wheels[1].repr ~= nil and self.wheels[1].repr ~= nil then
		local x,y,z = getTranslation(self.wheels[1].repr);
		local x2,y2,z2 = getTranslation(self.wheels[2].repr);

		self.averageYTranslation = (y + y2)/2;
	end;
	
	self.camTranslation = self.averageYTranslation;
	
end;

function seatCam:delete()
	if self.SeatPlaying ~= nil then
		stopSample(self.SeatSoundId);
	end;
end;

function seatCam:mouseEvent(posX, posY, isDown, isUp, button)
end;

function seatCam:keyEvent(unicode, sym, modifier, isDown)
end;

function seatCam:update(dt)
	if self.wheels[1].repr ~= nil and self.wheels[1].repr ~= nil then
		local x,y,z = getTranslation(self.wheels[1].repr);
		local x2,y2,z2 = getTranslation(self.wheels[2].repr);

		self.averageYTranslation = (y + y2)/2;
	end;
	
	--renderText(0.5, 0.65, 0.040, string.format(self.averageYTranslation));
	
	self.playSeatSound = false;
	if self.camTranslation > self.averageYTranslation then
		self.camTranslation = self.camTranslation - self.maxTranslationPrCycle * dt;
		if self.camTranslation < self.averageYTranslation then
			self.camTranslation = self.averageYTranslation;
		end;
	elseif self.camTranslation < self.averageYTranslation then
		self.camTranslation = self.camTranslation + self.maxTranslationPrCycle * dt;
		if self.camTranslation > self.averageYTranslation then
			self.camTranslation = self.averageYTranslation;
		end;
		--set sound to play if seat damping is very big.
		if self.camTranslation < self.averageYTranslation - 0.0002 and self.isEntered then
			self.playSeatSound = true;
		end;
	end;
	
	--renderText(0.5, 0.75, 0.040, string.format(self.camTranslation));
	
	if self.cameraRotNode ~= nil then
		setTranslation(self.cameraRotNode, self.startXTranslation, self.camTranslation+self.offsetAdjustmentTranslation, self.startZTranslation);
	end;
	
	--setup offsetAdjustmentTranslation accoding to weight on tractor
	if self.currentWeight ~= nil then
		self.offsetAdjustmentTranslation = -self.currentWeight * 1;
	else
		self.offsetAdjustmentTranslation = -0.37;
	end;
	
	self.offsetTranslation = self.camTranslation - self.startYTranslation;
	
	local adjustedOffsetTranslation = (self.offsetTranslation)+self.offsetAdjustmentTranslation;
	
	if self.seatNode ~= nil then
		setTranslation(self.seatNode, self.startSeatXTranslation, self.startSeatYTranslation + adjustedOffsetTranslation, self.startSeatZTranslation);
	end;
	
	if self.farmerNode ~= nil then
		setTranslation(self.farmerNode, self.startFarmerXTranslation, self.startFarmerYTranslation+adjustedOffsetTranslation, self.startFarmerZTranslation);
	end;
	
	if self.seatNode ~= nil then
		if self.playSeatSound and (self.camIndex == 2) then
			if not self.SeatPlaying then
				playSample(self.SeatSoundId, 0, 1, 0);
				self.SeatPlaying = true;
			end;
		else
			if self.SeatPlaying then
				stopSample(self.SeatSoundId);
				self.SeatPlaying = false;
			end;
		end;
	end;
end;

function seatCam:onLeave()
end;

function seatCam:draw()
end;

